@@ -1,11 +1,13 @@
+#' @export 
+
 BestFit <- function(obj, MSC, draw) {
   .GlobalEnv$x <- obj$time
   .GlobalEnv$y <- obj$thrs
   if (missing(draw)) 
     draw <- F
   
-  mFn <- c(1, 1, P3, 1, P5c, 1, P7c)
-  idx <- c(3, 5, 7)
+  mFn <- c(1, 1, P3, 1, P5c, P6c, P7c)
+  idx <- c(3, 5, 6, 7)
   obj$call <- NULL
   
   Mod <- which(MSC$AIC == min(MSC$AIC))
@@ -14,17 +16,17 @@ BestFit <- function(obj, MSC, draw) {
   
   oP <- MSC$param[idx2, ]
   
-  Opt <- optim(oP, Fn)
-  while (Opt$con) Opt <- optim(Opt$par, Fn)
+  Opt <- stats::optim(oP[1:Mod], Fn)
+  while (Opt$con) Opt <- stats::optim(Opt$par, Fn)
   opt <- Opt$par
   
   if (draw) {
-    X <- seq(0, max(obj$time), length.out = 1000)
+    X <- seq(0, max(obj$time), length.out = 100)
     
-    if (length(dev.list()) == 0) {
-      plot(obj$time, obj$thrs)
+    if (length(grDevices::dev.list()) == 0) {
+      graphics::plot(obj$time, obj$thrs)
     }
-    lines(X, Fn(opt, X), col = 2)
+    graphics::lines(X, Fn(opt, X), col = 2)
   }
 
   Y <- Fn(opt, obj$time)
@@ -42,7 +44,7 @@ BestFit <- function(obj, MSC, draw) {
   Res$resid <- obj$thrs - Y
   Res$Mod = Fn(Mod)$Mod
   Res$val = Opt$val
-  Res$R2 <- 1 - (var(obj$thrs - Y)/var(obj$thrs))
+  Res$R2 <- 1 - (stats::var(obj$thrs - Y)/stats::var(obj$thrs))
   
   on.exit(rm(list = c("x", "y"), envir = .GlobalEnv))
   class(Res) <- "dark"
