@@ -1,3 +1,5 @@
+#' @export 
+
 TestData <- function(x, theta, sse, repeatable) {
 	if (missing(repeatable)) 
 		repeatable = F
@@ -13,12 +15,12 @@ TestData <- function(x, theta, sse, repeatable) {
 		set.seed(143)
 
 	Len <- length(x)
-	Noise <- rnorm(Len, 0, sqrt(sse))
-	Y <- theta[1] + theta[2] * exp(-x * theta[3]) + theta[4] * (x - theta[5]) * H(x, 10, theta[5]) + theta[6] * (x - 
+	Noise <- stats::rnorm(Len, 0, sqrt(sse))
+	Y <- theta[1] + theta[2] * exp(-x / theta[3]) + theta[4] * (x - theta[5]) * H(x, 10, theta[5]) + theta[6] * (x - 
 		theta[7]) * H(x, 10, theta[7])
 
 	tmp <- list(call = match.call(), time = x, thrs = (Y + Noise), resid = Noise, fit = Y, thet = theta, sse = sse, 
-		val = var(Noise), data = paste("Test_data_", sse, sep = ""))
+		val = stats::var(Noise), data = paste("Test_data_", sse, sep = ""))
 	class(tmp) = "dark"
 	tmp
 }
\ No newline at end of file
